@@ -26,10 +26,7 @@ use self::errors::*;
 use dmntk_common::{DmntkError, HRef, OptHRef, Result};
 use dmntk_feel::{FeelType, Name};
 use std::convert::TryFrom;
-
-/// [Element] represents an element from another metamodel.
-#[derive(Debug, Clone, PartialEq)]
-pub struct Element;
+use std::fmt::Display;
 
 /// [DmnElement] is the abstract superclass for the Decision Model elements.
 /// It provides the optional attributes `id`, `description` and `label`,
@@ -48,6 +45,58 @@ pub trait DmnElement {
   fn extension_attributes(&self) -> &Vec<ExtensionAttribute>;
 }
 
+/// [NamedElement] adds the required attribute `name` to [DmnElement].
+pub trait NamedElement: DmnElement {
+  /// Returns the name of this element.
+  fn name(&self) -> &str;
+  /// Returns the optional `FEEL` name for this element.
+  fn feel_name(&self) -> &Option<Name>;
+}
+
+/// [Expression] is an abstract class that describes the logic
+/// by which a modeled decision shall be made, or pieces of that logic.
+pub trait Expression: DmnElement {
+  /// Optional namespace-prefixed name of the base type of this [Expression].
+  fn type_ref(&self) -> &Option<String>;
+}
+
+/// [FeelTypedElement] adds the `FEEL` type attributes to element.
+pub trait FeelTypedElement {
+  /// Returns the optional `FEEL` type for this element.
+  fn feel_type(&self) -> &Option<FeelType>;
+  /// Sets `FEEL` type for this element.
+  fn set_feel_type(&mut self, feel_type: FeelType);
+}
+
+/// [RequiredTypeRef] adds the required type reference to element.
+pub trait RequiredTypeRef {
+  /// Namespace-prefixed name of the base type of the implementor.
+  fn type_ref(&self) -> &str;
+}
+
+/// [RequiredVariable] adds the required reference to [InformationItem].
+pub trait RequiredVariable {
+  /// Returns the reference to [InformationItem].
+  fn variable(&self) -> &InformationItem;
+}
+
+/// `Invocable` is used to model the inputs of a decision whose values
+/// are defined outside of the decision model.
+pub trait Invocable: DmnElement + NamedElement + RequiredVariable {}
+
+/// The abstract class [BusinessContextElement], and its concrete specializations
+/// [PerformanceIndicator] and [OrganizationUnit] are placeholders,
+/// anticipating a definition to be adopted from other OMG meta-models,
+/// such as OMG OSM when it is further developed.
+pub trait BusinessContextElement: NamedElement {
+  /// The URI of this [BusinessContextElement].
+  fn uri(&self) -> &Option<String>;
+}
+
+/// [Element] represents an element from another metamodel.
+#[derive(Debug, Clone, PartialEq)]
+pub struct Element;
+
 /// The [ExtensionElement] element is a container to aggregate elements
 /// from other metamodels inside any [DmnElement].
 #[derive(Debug, Clone, PartialEq)]
@@ -70,31 +119,6 @@ pub struct ExtensionAttribute {
   pub value_ref: Option<Element>,
 }
 
-/// [NamedElement] adds the required attribute `name` to [DmnElement].
-pub trait NamedElement: DmnElement {
-  /// Returns the name of this element.
-  fn name(&self) -> &str;
-  /// Returns the optional `FEEL` name for this element.
-  fn feel_name(&self) -> &Option<Name>;
-}
-
-/// [FeelTypedElement] adds the `FEEL` type attributes to element.
-pub trait FeelTypedElement {
-  /// Returns the optional `FEEL` type for this element.
-  fn feel_type(&self) -> &Option<FeelType>;
-  /// Sets `FEEL` type for this element.
-  fn set_feel_type(&mut self, feel_type: FeelType);
-}
-
-/// The abstract class [BusinessContextElement], and its concrete specializations
-/// [PerformanceIndicator] and [OrganizationUnit] are placeholders,
-/// anticipating a definition to be adopted from other OMG meta-models,
-/// such as OMG OSM when it is further developed.
-pub trait BusinessContextElement: NamedElement {
-  /// The URI of this [BusinessContextElement].
-  fn uri(&self) -> &Option<String>;
-}
-
 /// Enumeration of concrete instances of [BusinessContextElement].
 #[derive(Debug, Clone)]
 pub enum BusinessContextElementInstance {
@@ -105,23 +129,23 @@ pub enum BusinessContextElementInstance {
 ///
 #[derive(Debug, Clone)]
 pub struct PerformanceIndicator {
-  /// Optional identifier of this this [InputData].
+  /// Optional identifier of this this [PerformanceIndicator].
   id: Option<String>,
-  /// Optional description of this [InputData].
+  /// Optional description of this [PerformanceIndicator].
   description: Option<String>,
-  /// An optional alternative short description of this [InputData].
+  /// An optional alternative short description of this [PerformanceIndicator].
   label: Option<String>,
-  /// Container to attach additional elements to any [InputData].
+  /// Container to attach additional elements to any [PerformanceIndicator].
   extension_elements: Option<ExtensionElement>,
-  /// Container to attach named extended attributes and model associations to any [InputData].
+  /// Container to attach named extended attributes and model associations to any [PerformanceIndicator].
   extension_attributes: Vec<ExtensionAttribute>,
   /// Name of this [PerformanceIndicator].
   name: String,
-  /// Optional `FEEL` name of this [ItemDefinition].
+  /// Optional `FEEL` name of this [PerformanceIndicator].
   feel_name: Option<Name>,
   /// The URI of this [PerformanceIndicator].
   uri: Option<String>,
-  /// Collection of [Decision] that impact this [PerformanceIndicator].
+  /// Collection of [Decision] that impact this [Perform`anceIndicator].
   /// This attribute stores references
   impacting_decisions: Vec<HRef>,
 }
@@ -187,7 +211,7 @@ pub struct OrganizationUnit {
   extension_attributes: Vec<ExtensionAttribute>,
   /// Name of this [OrganizationUnit].
   name: String,
-  /// Optional `FEEL` name of this [ItemDefinition].
+  /// Optional `FEEL` name of this [OrganizationUnit].
   feel_name: Option<Name>,
   /// The URI of this [OrganizationUnit].
   uri: Option<String>,
@@ -309,18 +333,6 @@ impl DrgElement {
   }
 }
 
-/// [Expression] is an abstract class that describes the logic
-/// by which a modeled decision shall be made, or pieces of that logic.
-pub trait Expression: DmnElement {
-  /// Optional namespace-prefixed name of the base type of this [Expression].
-  fn type_ref(&self) -> &Option<String>;
-}
-
-pub trait RequiredTypeRef {
-  /// Namespace-prefixed name of the base type of the implementor.
-  fn type_ref(&self) -> &str;
-}
-
 /// [Definitions] element is the outermost containing object
 /// for all elements of a DMN decision model.
 /// It defines the scope of visibility and the namespace
@@ -486,6 +498,21 @@ impl Definitions {
       None
     })
   }
+  /// Returns a vector of references to decision services.
+  pub fn decision_services(&self) -> Vec<&DecisionService> {
+    self
+      .drg_elements
+      .iter()
+      .filter_map(|drg_element| {
+        if drg_element.is_decision_service() {
+          if let DrgElement::DecisionService(inner) = drg_element {
+            return Some(inner);
+          }
+        }
+        None
+      })
+      .collect()
+  }
   /// Returns an optional reference to [DecisionService] with specified identifier
   /// or [None] when such [DecisionService] was not found among instances of [DrgElement].
   pub fn decision_service_by_id(&self, id: &str) -> Option<&DecisionService> {
@@ -697,8 +724,9 @@ pub struct InputData {
   variable: InformationItem,
 }
 
-impl InputData {
-  pub fn variable(&self) -> &InformationItem {
+impl RequiredVariable for InputData {
+  /// Returns reference to a variable for this [BusinessKnowledgeModel].  
+  fn variable(&self) -> &InformationItem {
     &self.variable
   }
 }
@@ -752,8 +780,12 @@ pub struct Import {
 }
 
 /// Enumeration of concrete instances of abstract [Expression], which are:
-/// - [LiteralExpression], and
-/// - [Invocation].  
+/// - [Context],
+/// - [DecisionTable],
+/// - [FunctionDefinition],
+/// - [Invocation],
+/// - [LiteralExpression],
+/// - [Relation].
 #[derive(Debug, Clone, PartialEq)]
 pub enum ExpressionInstance {
   Context(Context),
@@ -761,7 +793,6 @@ pub enum ExpressionInstance {
   FunctionDefinition(Box<FunctionDefinition>),
   Invocation(Box<Invocation>),
   LiteralExpression(LiteralExpression),
-  UnaryTests,
   Relation(Relation),
 }
 
@@ -816,12 +847,15 @@ pub struct LiteralExpression {
 }
 
 impl LiteralExpression {
+  ///
   pub fn text(&self) -> &Option<String> {
     &self.text
   }
+  ///
   pub fn expression_language(&self) -> Option<String> {
     self.expression_language.clone()
   }
+  ///
   pub fn imported_values(&self) -> Option<Import> {
     self.imported_values.clone()
   }
@@ -851,6 +885,7 @@ impl DmnElement for LiteralExpression {
 }
 
 impl Expression for LiteralExpression {
+  /// Returns an optional type reference.
   fn type_ref(&self) -> &Option<String> {
     &self.type_ref
   }
@@ -1224,15 +1259,6 @@ impl NamedElement for KnowledgeSource {
   }
 }
 
-/// `Invocable` is used to model the inputs of a decision whose values
-/// are defined outside of the decision model.
-pub trait Invocable: DmnElement + NamedElement {
-  /// Returns reference to a variable that is bound to the
-  /// function defined by the [FunctionDefinition], allowing
-  /// decision logic to invoke the function by name.
-  fn variable(&self) -> &InformationItem;
-}
-
 /// Instances of `Invocable` interface.
 #[derive(Debug, Clone)]
 pub enum InvocableInstance {
@@ -1318,7 +1344,7 @@ impl NamedElement for BusinessKnowledgeModel {
   }
 }
 
-impl Invocable for BusinessKnowledgeModel {
+impl RequiredVariable for BusinessKnowledgeModel {
   /// Returns reference to a variable for this [BusinessKnowledgeModel].
   fn variable(&self) -> &InformationItem {
     &self.variable
@@ -1356,17 +1382,17 @@ pub struct DecisionService {
 }
 
 impl DecisionService {
-  /// Returns a reference to collection of references to output [Decision]s for this [DecisionService].
-  pub fn output_decisions(&self) -> &Vec<HRef> {
-    &self.output_decisions
+  /// Returns a reference to collection of references to input [Decision]s for this [DecisionService].
+  pub fn input_decisions(&self) -> &Vec<HRef> {
+    &self.input_decisions
   }
   /// Returns a reference to collection of references to encapsulated [Decision]s for this [DecisionService].
   pub fn encapsulated_decisions(&self) -> &Vec<HRef> {
     &self.encapsulated_decisions
   }
-  /// Returns a reference to collection of references to input [Decision]s for this [DecisionService].
-  pub fn input_decisions(&self) -> &Vec<HRef> {
-    &self.input_decisions
+  /// Returns a reference to collection of references to output [Decision]s for this [DecisionService].
+  pub fn output_decisions(&self) -> &Vec<HRef> {
+    &self.output_decisions
   }
   /// Returns a reference to collection of references to [InputData] for this [DecisionService].
   pub fn input_data(&self) -> &Vec<HRef> {
@@ -1408,7 +1434,7 @@ impl NamedElement for DecisionService {
   }
 }
 
-impl Invocable for DecisionService {
+impl RequiredVariable for DecisionService {
   /// Returns reference to a variable for this [DecisionService].
   fn variable(&self) -> &InformationItem {
     &self.variable
@@ -1823,7 +1849,7 @@ pub struct DecisionTable {
   pub output_label: Option<String>,
 }
 
-/// Implementation of Display trait for DecisionTable.
+/// Implementation of [Display] for [DecisionTable].
 impl std::fmt::Display for DecisionTable {
   fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
     let mut buffer = String::new();
@@ -1863,8 +1889,8 @@ pub enum DecisionTableOrientation {
   CrossTable,
 }
 
-/// Implementation of Display trait for DecisionTableOrientation.
-impl std::fmt::Display for DecisionTableOrientation {
+/// Implementation of [Display] for [DecisionTableOrientation].
+impl Display for DecisionTableOrientation {
   fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
     match self {
       DecisionTableOrientation::RuleAsRow => write!(f, "Rule-as-Row"),
@@ -1913,7 +1939,7 @@ pub enum HitPolicy {
   RuleOrder,
 }
 
-/// Implementation of Display trait for HitPolicy.
+/// Implementation of [Display] for HitPolicy.
 impl std::fmt::Display for HitPolicy {
   fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
     match self {
@@ -1964,7 +1990,7 @@ pub enum BuiltinAggregator {
   Max,
 }
 
-/// Implementation of Display trait for BuiltinAggregator.
+/// Implementation of [Display] for [BuiltinAggregator].
 impl std::fmt::Display for BuiltinAggregator {
   fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
     write!(
