@@ -51,8 +51,8 @@ const NODE_DMNDI_LABEL_HORIZONTAL_ALIGNMENT: &str = "labelHorizontalAlignment";
 const NODE_DMNDI_LABEL_VERTICAL_ALIGNMENT: &str = "labelVerticalAlignment";
 const NODE_DMNDI_LABEL: &str = "DMNLabel";
 const NODE_DMNDI_DECISION_SERVICE_DIVIDER_LINE: &str = "DMNDecisionServiceDividerLine";
-const NODE_OUTPUT_DECISION: &str = "outputDecision";
 const NODE_DESCRIPTION: &str = "description";
+const NODE_ENCAPSULATED_DECISION: &str = "encapsulatedDecision";
 const NODE_ENCAPSULATED_LOGIC: &str = "encapsulatedLogic";
 const NODE_FUNCTION_DEFINITION: &str = "functionDefinition";
 const NODE_FORMAL_PARAMETER: &str = "formalParameter";
@@ -60,6 +60,7 @@ const NODE_FUNCTION_ITEM: &str = "functionItem";
 const NODE_INFORMATION_REQUIREMENT: &str = "informationRequirement";
 const NODE_INPUT_DATA: &str = "inputData";
 const NODE_INPUT: &str = "input";
+const NODE_INPUT_DECISION: &str = "inputDecision";
 const NODE_INPUT_ENTRY: &str = "inputEntry";
 const NODE_INPUT_EXPRESSION: &str = "inputExpression";
 const NODE_INPUT_VALUES: &str = "inputValues";
@@ -70,6 +71,7 @@ const NODE_KNOWLEDGE_REQUIREMENT: &str = "knowledgeRequirement";
 const NODE_KNOWLEDGE_SOURCE: &str = "knowledgeSource";
 const NODE_LITERAL_EXPRESSION: &str = "literalExpression";
 const NODE_OUTPUT: &str = "output";
+const NODE_OUTPUT_DECISION: &str = "outputDecision";
 const NODE_OUTPUT_ENTRY: &str = "outputEntry";
 const NODE_OUTPUT_VALUES: &str = "outputValues";
 const NODE_PARAMETER: &str = "parameter";
@@ -178,7 +180,7 @@ impl ModelParser {
       let item_components_definitions = self.parse_item_definitions(child_node, NODE_ITEM_COMPONENT)?;
       let item_definition = ItemDefinition {
         name: required_name(child_node)?,
-        feel_name: optional_feel_name(node)?,
+        feel_name: optional_feel_name(child_node)?,
         id: optional_attribute(child_node, ATTR_ID),
         description: optional_child_optional_content(child_node, NODE_DESCRIPTION),
         label: optional_attribute(child_node, ATTR_LABEL),
@@ -306,9 +308,9 @@ impl ModelParser {
         extension_attributes: vec![],
         variable: self.parse_information_item_child(child_node, NODE_VARIABLE)?,
         output_decisions: self.required_hrefs_in_child_nodes(child_node, NODE_OUTPUT_DECISION)?,
-        encapsulated_decisions: self.required_hrefs_in_child_nodes(child_node, NODE_OUTPUT_DECISION)?,
-        input_decisions: self.required_hrefs_in_child_nodes(child_node, NODE_OUTPUT_DECISION)?,
-        input_data: self.required_hrefs_in_child_nodes(child_node, NODE_OUTPUT_DECISION)?,
+        encapsulated_decisions: self.required_hrefs_in_child_nodes(child_node, NODE_ENCAPSULATED_DECISION)?,
+        input_decisions: self.required_hrefs_in_child_nodes(child_node, NODE_INPUT_DECISION)?,
+        input_data: self.required_hrefs_in_child_nodes(child_node, NODE_INPUT_DATA)?,
       };
       drg_elements.push(DrgElement::DecisionService(decision_service));
     }
@@ -489,7 +491,6 @@ impl ModelParser {
     if let Some(literal_expression) = self.parse_optional_literal_expression(node) {
       return Ok(Some(ExpressionInstance::LiteralExpression(literal_expression)));
     }
-    //TODO add unary tests
     if let Some(relation) = self.parse_optional_relation(node)? {
       return Ok(Some(ExpressionInstance::Relation(relation)));
     }
