@@ -284,7 +284,7 @@ fn _2_0009() {
 fn _2_0010() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_2_0010, "file://2_0010.dmn").unwrap();
-  assert_eq!("_00559901-ef96-4bd2-9301-58204de7a888", definitions.id().as_ref().unwrap().as_str());
+  assert_eq!("_a4a902f2-1948-4e06-8035-da8098345536", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
@@ -298,13 +298,13 @@ fn _2_0106() {
 fn _3_0001() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0001, "file://3_0001.dmn").unwrap();
-  assert_eq!("_180a340c-6910-41a7-ab7e-8739f70fb91a", definitions.id().as_ref().unwrap().as_str());
+  assert_eq!("_8e0912d6-54f3-4276-81a5-eebc712af710", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
 fn _3_0002() {
   let definitions = crate::parse(dmntk_examples::DMN_3_0002, "file:///3_0002.dmn").unwrap();
-  assert_eq!("_c2dc9bd5-010e-4351-b375-7db74d8ba69d", definitions.id().as_ref().unwrap().as_str());
+  assert_eq!("_536af77f-8f8b-4339-b00d-28116bb0c3f8", definitions.id().as_ref().unwrap().as_str());
   // <definitions>.<decision>
   let decision = definitions.decision_by_id("_de5529b1-ed4c-4b39-9e36-e0e056aec20c").unwrap();
   assert_eq!("_de5529b1-ed4c-4b39-9e36-e0e056aec20c", decision.id().as_ref().unwrap().as_str());
@@ -338,28 +338,28 @@ fn _3_0003() {
 fn _3_0004() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0004, "file://3_0004.dmn").unwrap();
-  assert_eq!("_a0f3517d-ee37-4724-8beb-81d28b145e17", definitions.id().as_ref().unwrap().as_str());
+  assert_eq!("_52650d27-fc13-463e-a55a-2080e8a1c8da", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
 fn _3_0006() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0006, "file://3_0006.dmn").unwrap();
-  assert_eq!("_7a8aaf11-5415-4d91-92c0-f9f1a26ba81d", definitions.id().as_ref().unwrap().as_str());
+  assert_eq!("_40a27b80-d50e-4e60-9905-178d5e3065e3", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
 fn _3_0007() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0007, "file://3_0007.dmn").unwrap();
-  assert_eq!("_69430b3e-17b8-430d-b760-c505bf6469f9", definitions.id().as_ref().unwrap().as_str());
+  assert_eq!("_0705a5f4-80df-41b5-9553-79c1ba3dff6c", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
 fn _3_0008() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0008, "file://3_0008.dmn").unwrap();
-  assert_eq!("_ba93cb90-ea2e-4b18-8915-7a5493c52e34", definitions.id().as_ref().unwrap().as_str());
+  assert_eq!("_15af8727-45c8-4dc8-8435-ed087bfb35d9", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
@@ -426,7 +426,7 @@ fn _3_0082() {
 fn _3_0085() {
   // <definitions>
   let definitions = crate::parse(dmntk_examples::DMN_3_0085, "file://3_0085.dmn").unwrap();
-  assert_eq!("_56ed8ec7-c342-4abc-9278-27b46ca991c6", definitions.id().as_ref().unwrap().as_str());
+  assert_eq!("_3e0df83c-a19e-4d31-98e0-b73db25df89c", definitions.id().as_ref().unwrap().as_str());
 }
 
 #[test]
@@ -438,7 +438,11 @@ fn _3_0087() {
   let knowledge_source = definitions.knowledge_source_by_id("_989d137f-86ff-4249-813f-af67c08a2762").unwrap();
   assert_eq!("_989d137f-86ff-4249-813f-af67c08a2762", knowledge_source.id().as_ref().unwrap().as_str());
   assert_eq!("Credit officer", knowledge_source.name());
-  assert_eq!(r#"Credit officer"#, knowledge_source.feel_name().as_ref().unwrap().to_string());
+  assert_eq!("Credit officer", knowledge_source.feel_name().as_ref().unwrap().to_string());
+  assert_eq!(
+    r#"Name(["Credit", "officer"])"#,
+    format!("{:?}", knowledge_source.feel_name().as_ref().unwrap())
+  );
 }
 
 #[test]
